@@ -11,8 +11,8 @@
 ;;
 ;; Created: February 13, 2018
 ;; Modified: December 15, 2018
-;; Package-Version: 2.1.0
-;; Package-Revision: 0dc7f1ec81fa
+;; Package-Version: 20250514.1107
+;; Package-Revision: 7b08ce315c0b
 ;; Keywords: unix convenience
 ;; Package-Requires: ((emacs "25.1") (s "1.13.0") (compat "29.1.4.2"))
 ;;
@@ -110,7 +110,10 @@ Override this to your own value for mocking out shell calls in tests.")
     map)
   "Keymap for daemons mode.")
 
-(defvar daemons-output-mode-map (copy-keymap daemons-mode-map)
+(defvar daemons-output-mode-map
+  (let ((map (copy-keymap daemons-mode-map)))
+    (define-key map [remap revert-buffer] 'daemons-status-at-point)
+    map)
   "Keymap for daemons output mode.")
 
 ;; TODO this needs to become buffer-local
@@ -393,7 +396,7 @@ FORMS begins with a plist with these properties:
 
         This could be something like:
         (and (eq system-type \\='gnu/linux)
-             (eq 0 (daemons--shell-command \"which service\")))
+             (executable-find \"service\"))
 
 :commands - An alist of user commands (see `daemons--commands-alist')
 
